    #Script by by Joshua Driggs (zapwizard at gmail.com)

    # This script will let people apply their choice of default material to all the left over defaults in their model.
    # This means users don't have to manually apply no_draw or grey_grid to each and every left over face in the model.
    # This script will also remove any material that is on a reversed face, or applied overall to a model.

    require 'sketchup.rb'

    ## Menu and GUI code
    #-----------------------------------------------------------------------------
module SU_Source_tools_apply
    def SU_Source_tools_apply.variables
      @group_list = []
      @component_list = []
      @materialize_these = []
      @badtextures = []
      @model_list = Sketchup.active_model.entities
    end

    def SU_Source_tools_apply.applymaterial
       @materialize_these.each do |item|
          current = Sketchup.active_model.materials.current
          m = item.material = current
       end
    end

    def SU_Source_tools_apply.start
      model = Sketchup.active_model
      model.start_operation "ApplyCurrent"
      variables
      traverse_model_entities
      #list the number of faces the material was applied to
      total = @materialize_these.length
      badtextotal = @badtextures.length
      applymaterial
      ##Sketchup.active_model.entities.erase_entities(@materialize_these)
      model.commit_operation
     
      UI.messagebox("The current material has been applied to #{total} faces.
      There were #{badtextotal} incorrectly applied materials that were removed.")
    end

    def SU_Source_tools_apply.traverse_model_entities
    # @model_list will not be empty until all of the groups, components
    # and edges have been traversed.
       while @model_list != []
       @model_list.each do |item|
          # Determine if the entity is an edge, group, face, or component.
          type = item.typename
          case type
             when "Group"
             # Add each of the entities in the group into the group_list
             # array.
                item.entities.each do |entity|
                   @group_list.push entity
                end
             # Check to see if a material was universally applied to a group
                if item.material != nil then
                   @badtextures.push item
                   item.material = nil
                end
             when "ComponentInstance"
                # .entities can be called on a Component Definition, but not on
                # a Component Instance.
                # Use the .definition method to access the Component Definition
                # that the instance belongs to.
                item.definition.entities.each do |entity|
                   # Add each of the entities in the component into the
                   # component_list array.
                   @component_list.push entity
                end
                # Check to see if a material was universally applied to a component
                if item.material != nil then
                   @badtextures.push item
                   item.material = nil
                end
             when "Face"
             #Check all faces for materials applied to a reversed face, and remove the material.
             #Remove backside materials
                #puts "face"
                if item.back_material != nil then
                   @badtextures.push item
                   item.back_material = nil
                end
             #Apply No_Draw to front side material if there isn't already a material applied.
                if item.material == nil then
                   @materialize_these.push item            
                end
          end
        end
        # Update the @model_list so it contains only the entities that were
        # embedded in groups or components. These entities haven't been
        # counted yet.
        @model_list = @group_list + @component_list
        # Clear out the group and component lists so they're ready for the
        # next level of sub-groups/components.
        @group_list = []
        @component_list =[]
      end

    end
	
end
	

    #-----------------------------------------------------------------------------

	if !file_loaded?('source_sutools') then
		$source_sutools_menu = UI.menu("Plugins").add_submenu("* Source SU Tools *")
	end
	if !file_loaded?(__FILE__) then
		$source_sutools_menu.add_item("Apply Current Material") { SU_Source_tools_apply.start  }
	end


file_loaded('source_sutools')
file_loaded(__FILE__)